import SwiftUI

struct MainMenuView: View {
    @State
    private var currentGame: IngameVM? = nil
    
    var body: some View {
        VStack(spacing: 20) {
            Spacer()
            
            Label {
                Text("appNameBannerTitle").font(.largeTitle)
            } icon: {
                Image(.mainMenu).resizable().scaledToFit()
            }.labelStyle(VerticalLabelStyle())
            
            Spacer()
            
            NavigationLink(destination: NewGameView(currentGame: $currentGame).navigationTitle("newGame.title")) {
                Label("mainMenu.button.newGame", systemImage: "play")
            }
            
            NavigationLink(destination: SavedGamesView(currentGame: $currentGame).navigationTitle("savedGames.title")) {
                Label("mainMenu.button.scoreboard", systemImage: "rosette")
            }
            
            Spacer()
        }.navigationDestination(isPresented: self.$currentGame.map(get: { $0 != nil }, setWithContext: {
            game, presented in
            if presented {
                game
            } else {
                nil
            }
        }), destination: {
            NavigationLazyView(IngameView(vm: currentGame!))
        })
    }
}

private struct VerticalLabelStyle: LabelStyle {
    func makeBody(configuration: Configuration) -> some View {
        VStack(alignment: .center, spacing: 30) {
            configuration.icon
            configuration.title
        }
    }
}

#Preview {
    MainMenuView()
}
