import SwiftUI

struct SavedGamesView: View {
    @StateObject
    private var vm = SavedGamesVM()
    
    @Binding
    var currentGame: IngameVM?
    
    var body: some View {
        TabView {
            ScoreboardView(results: self.$vm.unfinished, currentGame: $currentGame, "scoreboard.table.column.players") {
                result in
                let n1 = if result.player1Name != nil {
                    Text(result.player1Name!)
                } else {
                    Text(LocalizedStringKey(result.player1Type.baseTranslationKey))
                }
                let n2 = if result.player2Name != nil {
                    Text(result.player2Name!)
                } else {
                    Text(LocalizedStringKey(result.player2Type.baseTranslationKey))
                }
                
                return LocalizedStringKey("\(n1) savedGames.section.unfinished.entry \(n2)")
            }.tabItem {
                Label("savedGames.section.unfinished", systemImage: "play.rectangle")
            }.badge("savedGames.section.unfinished.badge \(self.vm.unfinished.count)")
            
            ScoreboardView(results: self.$vm.finished, currentGame: $currentGame, "scoreboard.table.column.players") {
                result in
                let n1 = if result.player1Name != nil {
                    Text(result.player1Name!)
                } else {
                    Text(LocalizedStringKey(result.player1Type.baseTranslationKey))
                }
                let n2 = if result.player2Name != nil {
                    Text(result.player2Name!)
                } else {
                    Text(LocalizedStringKey(result.player2Type.baseTranslationKey))
                }
                
                return LocalizedStringKey("\(n1) savedGames.section.finished.entry \(n2)")
            }.tabItem {
                Label("savedGames.section.finished", systemImage: "rosette")
            }
        }
        .tabViewStyle(.automatic)
    }
}

#Preview {
    SavedGamesView(currentGame: .constant(nil))
}
